#!/bin/bash

# install.sh							
# 
# Installs the Birthday Notifier script
#
# Copyright (C) 2010 Barun Kumar Saha
#
# This script is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License, or (at your option) any later version.
#
# This module is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.


### Sub functions ###

#
# Name:		display_usage
# Inputs:	None
# Output:	Displays the different options available for use
#
function display_usage {
	echo "Usage: $0 [OPTIONS]"
	echo ""
	echo -ne "\t-h, --help"
	echo -e	 "\tDisplay the help on this command"
}

#
# Name:		trim
# Inputs:	A string
# Output:	String with leading and trailing white spaces removed
#
function trim {
	string="$1"
	string=`echo "$1" | sed s/'^ *'// | sed s/' *$'//`
	echo "$string"
}


### Main program ###

# Won't run in Bourne shell
if [ `basename $SHELL` = 'sh' ]
then
	echo 'It seems you are using Bourne shell. This script will not run on Bourne shell.'
	echo 'If you are using any other shell, then set the SHELL environment variable, and then run this installer script.'
	echo 'For example,'
	echo '    SHELL=/bin/bash'
	exit 1
fi

while [ "$#" -gt 0 ]
do
	case "$1" in
		-h | --help)
			display_usage
			;;
		*)
			echo "Invalid option used!" 1>&2
			display_usage
			exit 1
			;;
	esac
done

echo "Please wait for a moment while the script is being installed"
echo ""

echo -n "Checking for profile file ... "
if [ -f $HOME/.profile ]
then
	profile_file_name=$HOME/.profile
elif [ -f $HOME/.bash_profile ]
then
	profile_file_name=$HOME/.bash_profile
elif [ -f $HOME/.ksh_profile ]
then
	profile_file_name=$HOME/.ksh_profile
else
	echo "No .profile or .bash_profile or .ksh_profile found in your home directory!"
	echo "Exiting ..."
	exit 1
fi
echo "Found $profile_file_name"


echo -n "Checking --date option for GNU date command ... "
date --date '1 day' 1> /dev/null 2>&1
if [ $? -eq 0 ]
then
	echo "OK"
else
	echo "Not found"
	echo "You need to install GNU date to use this program"
	echo "Exiting ..."
	exit 2
fi

target_dir="$HOME/bday_notify"
echo -n "Creating directory $target_dir ... "

[ -d "$target_dir" ] || mkdir "$target_dir"
if [ $? -eq 0 ]
then
	echo "OK"
else
	echo "Failed to create the directory!"
	echo "Exiting ..."
	exit 1
fi

echo -n "Copying files to $target_dir ... "

cp -f ./notify_bday.sh ./bday.dat ./LICENSE ./README "$target_dir"
if [ $? -eq 0 ]
then
	echo "OK"
else
	echo "Failed to copy one or more file(s)"
	echo "Exiting ..."
	exit 3
fi

echo -n "Installing the script with default options ... "
echo ""	>> "$profile_file_name"
echo "# Birthday notifications script" >> "$profile_file_name"
echo "$target_dir/notify_bday.sh --days 7 &" >> "$profile_file_name"

if [ $? -eq 0 ]
then
	echo "OK"
else
	echo "Failed to install the script!"
	echo "Exiting ..."
	exit 1
fi

echo ""
echo "To change the default settings, edit the $profile_file_name file"
echo "Execute '$target_dir/notify_bday.sh --help' to know about more options"
echo "Edit the $target_dir/bday.dat file to add/remove event dates"
echo ""
echo "Done"

exit 0
